dofilepath("data:scripts\\race.lua")
dofilepath("player:MissionGrid_record.lua")


--------------------------------------------------------------------------------
-- create and display pings for map exits
--
function Rule_EnableExits()
	local playerIndex = 0

	-- create pings
	for i, iCount in exitSpheres[currentMission] do
		if (iCount) then
			local pingid = Ping_AddPoint(iCount[4], "anomaly", iCount[1])
			Ping_LabelVisible(pingid, 1)
		end
	end

	-- done here
	Rule_Remove( "Rule_EnableExits" )

	-- create sobgroups to be filled later by Rule_CheckMapExitsForMotherships
	SobGroup_Create("ShipsInVolume")
	SobGroup_Create("MSInVolume")

	-- now check if the mothership is inside one of the pings, and end the mission if it is
	Rule_AddInterval("Rule_CheckMapExitsForMotherships", 2)
end


--------------------------------------------------------------------------------
-- check if mothership is in volume, then restart map
--
sphereCount = 1
function Rule_CheckMapExitsForMotherships()
	local playerIndex = 0
	local i = sphereCount
	local iCount = exitSpheres[currentMission][sphereCount]
	if (iCount) then
		Player_FillSobGroupInVolume("ShipsInVolume", playerIndex, iCount[1])
		for j = 1, getn(motherships) do
			SobGroup_FillShipsByType("MSInVolume", "ShipsInVolume", motherships[j])
		end
		if (SobGroup_Empty("MSInVolume") == 0) then
			Rule_Remove( "Rule_CheckMapExitsForMotherships" )
			campaignStarted = 1
			sectorsCleared[currentMission] = 1
			nextMission = currentMission + addMissions[i]
			Player_InstantlyGatherAllResources( playerIndex )
			SaveCampaignStatus()
			-- could use a prompt here to ask the player if he wishes to coninue or exit
--			FE_Retire("")			-- shows a scary prompt and executes the commands contained in the string, then behaves the same as setMissionComplete(0)
--			FE_ExitToMainMenu()		-- exits to main menu
--			setMissionComplete(0)		-- no effect?
			-- generates persistN.lua where N is the next mission
			-- then 1. does nothing if the campaign file does not have the postlevel parameter configured, or 2. pops the player back to the main menu if it is
			-- if you use FE_RestartGame(0) in conjunction with this function then the "scenario" parameter for the campaign in PLAYERCFG.LUA gets iterated backward (to zero in our case), causing PLAYERCFG.LUA to become corrupt and the game to crash on the next mission
			-- so it may be necessary to to exit to main menu after each mission if you use this
			setMissionComplete(1)
--			setMissionComplete(0)		-- 1. does nothing if the campaign file does not have the postlevel parameter configured, or 2. pops up a menu asking to restart, load a game, exit, etc. if it is
--			setGameOver()			-- same as setMissionComplete(1)
--			FE_RestartGame(0)		-- restarts the current mission
			return
		end
		SobGroup_Clear("ShipsInVolume")
		SobGroup_Clear("MSInVolume")
	end
	sphereCount = sphereCount + 1
	if (sphereCount > 4) then
		sphereCount = 1
	end
end


-------------------------------------------------------------------------------
-- returns the HW2 pathname
-- can't remember the author of this script
function GetHW2Path_old()
	execute("dir > dir.txt")
	readfrom("dir.txt")
	local filestring = read("*a")
	local start_of_string
	local count = 65
	while not start_of_string and count < (65 + 26) do
		start_of_string = strfind(filestring, strchar(count) .. ":\\")
		count = count + 1
	end
	if start_of_string then
		return strsub(filestring, start_of_string, strfind(filestring, "\\Bin\\Release"))
	end
end

-- so much simpler!
function GetHW2Path()
	return "../../"
end


-------------------------------------------------------------------------------
-- get the name of the player's current profile
--
function GetProfilePath()
	local ProfileIni = HW2Path .. "Bin\\local.ini"
	readfrom(ProfileIni)
	local dum, ProfileStr = read("*l", "*l")
	local idx1, idx2 = strfind(ProfileStr, "currentprofile=", 1, 1)
	return strsub(ProfileStr, idx2 + 1, -1)
end


-------------------------------------------------------------------------------
-- load persistant data, ships are loaded in levels
--
function LoadPersistentData_Mission()
	if (campaignStarted == 0) then
		SobGroup_ExitHyperSpace("MS_StartGroup", "MS_StartVolume")
	else
		local filein = HW2Path .. "Bin\\Profiles\\" .. ProfilePath .. "\\Campaign\\ASCENSION\\persist2.lua"
		local fileout = HW2Path .. "Bin\\Profiles\\" .. ProfilePath .. "\\Campaign\\ASCENSION\\persist1.lua"
		rename(filein, fileout)
		SobGroup_LoadPersistantData("Hgn_Mothership")
		SobGroup_Create("MS_StartGroup")
		Player_FillShipsByType("MS_StartGroup", 0, "Hgn_Mothership")
	end
end


-------------------------------------------------------------------------------
-- save persistant data
--
function SaveCampaignStatus()
	local playerIndex = 0
	local iRace = Player_GetRace(playerIndex) + 1
	local WriteString = ""

	WriteString = WriteString
	.. "campaignStarted = " .. campaignStarted .. "\n"
	.. "currentMission = " .. nextMission .."\n"
	.. "sectorsCleared = {"
	for i = 1, getn(sectorsCleared) do
		WriteString = WriteString .. sectorsCleared[i] .. ","
	end
	WriteString = WriteString .. "}\n\n"

	-- actually write everything
	local WriteFile = HW2Path .. "Bin\\Profiles\\" .. ProfilePath .. "\\Campaign\\ASCENSION\\MissionGrid_record.lua"
	writeto(WriteFile)
	write(WriteString)
end

-- call these ONCE
HW2Path = GetHW2Path()
ProfilePath = GetProfilePath()
